@@ -15,6 +15,9 @@
 #undef LOCALEDIR
 #undef HAVE_LIBREADLINE
 #undef WITH_GGZ
+#undef HAVE_INET_NTOP
+#undef GETTEXT_PACKAGE
+#undef HAVE_PTHREADS
 
 @BOTTOM@
 #endif /* FC_CONFIG_H */
