@@ -1,4 +1,4 @@
-/*	$Id: cards.h,v 1.7 2001/09/03 00:55:40 riq Exp $	*/
+/*	$Id: cards.h,v 1.8 2002/08/31 17:45:58 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -24,7 +24,7 @@
 #ifndef __TEG_GUI_GNOME_CARDS_H
 #define __TEG_GUI_GNOME_CARDS_H
 
-void cards_view( int pais);
+void cards_view( int country);
 void cards_update( void );
 void cards_update_para_canje( void );
 void cards_delete( int p1, int p2, int p3 );
