@@ -1,4 +1,4 @@
-/*	$Id: themes.c,v 1.18 2001/11/10 18:56:35 riq Exp $	*/
+/*	$Id: themes.c,v 1.32 2003/09/08 06:18:12 edomat Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2001 Ricardo Quesada
@@ -18,12 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/**
- * @file themes.c
- * File that parse the theme stuff
- */
-
 /*
+ * File that parse the theme stuff
  * File based in the job example from libxml
  */
 
@@ -38,15 +34,19 @@
 #include <glib.h>
 
 #include "all.h"
+#include "themes.h"
 #include "globals.h"
 #include "common.h"
-#include "themes.h"
 
 #ifndef xmlChildrenNode
 #define xmlChildrenNode childs
 #define xmlRootNode root
 #endif
 
+#undef _DEBUG
+
+#define TEG_THEME_VER_MAJOR (1)
+#define TEG_THEME_VER_MINOR (5)
 
 static pTheme g_theme = NULL;	/**< Current theme */
 static pTInfo g_tinfo = NULL;	/**< info of all current themes */
@@ -66,30 +66,42 @@ parseCountry(xmlDocPtr doc, xmlNodePtr cur)
 	memset(ret, 0, sizeof(*ret));
 	
 	ret->name = xmlGetProp(cur, (const xmlChar *) "name");
-	if (ret->name == NULL)
-		fprintf(stderr, "Country has no name\n");
+	if (ret->name == NULL) {
+		fprintf(stderr, "XML: 'country' has no 'name'\n");
+		goto error;
+	}
 
 	ret->file = xmlGetProp(cur, (const xmlChar *) "file");
-	if (ret->file == NULL)
-		fprintf(stderr, "Country has no file\n");
+	if (ret->file == NULL) {
+		fprintf(stderr, "XML: 'country' has no 'file'\n");
+		goto error;
+	}
 
 	ret->pos_x = xmlGetProp(cur, (const xmlChar *) "pos_x");
-	if (ret->pos_x == NULL)
-		fprintf(stderr, "Country has no pos_x\n");
+	if (ret->pos_x == NULL) {
+		fprintf(stderr, "XML: 'country' has no 'pos_x'\n");
+		goto error;
+	}
 
 	ret->pos_y = xmlGetProp(cur, (const xmlChar *) "pos_y");
-	if (ret->pos_y == NULL)
-		fprintf(stderr, "Country has no pos_y\n");
+	if (ret->pos_y == NULL) {
+		fprintf(stderr, "XML: 'country' has no 'pos_y'\n");
+		goto error;
+	}
 
 	ret->army_x = xmlGetProp(cur, (const xmlChar *) "army_x");
-	if (ret->army_x == NULL)
-		fprintf(stderr, "Country has no army_x\n");
+	if (ret->army_x == NULL) {
+		fprintf(stderr, "XML: 'country' has no 'army_x'\n");
+		goto error;
+	}
 
 	ret->army_y = xmlGetProp(cur, (const xmlChar *) "army_y");
-	if (ret->army_y == NULL)
-		fprintf(stderr, "Country has no army_y\n");
+	if (ret->army_y == NULL) {
+		fprintf(stderr, "XML: 'country' has no 'army_y'\n");
+		goto error;
+	}
 
-	cur = cur->xmlChildrenNode;
+	cur = xml_get_element_children( cur );
 
 	if ( cur != NULL ) {
 		fprintf(stderr,"Wrong type (%s). Nothing was expected\n", cur->name);
@@ -98,6 +110,10 @@ parseCountry(xmlDocPtr doc, xmlNodePtr cur)
 	}
 
 	return(ret);
+
+error:
+	free(ret);
+	return NULL;
 }
 
 static pContinent
@@ -116,18 +132,24 @@ parseContinent(xmlDocPtr doc, xmlNodePtr cur)
 	memset(ret, 0, sizeof(*ret));
 	
 	ret->name = xmlGetProp(cur, (const xmlChar *) "name");
-	if (ret->name == NULL)
-		fprintf(stderr, "Continent has no name\n");
+	if (ret->name == NULL) {
+		fprintf(stderr, "XML: 'continent' has no 'name'\n");
+		goto error;
+	}
 
 	ret->pos_x = xmlGetProp(cur, (const xmlChar *) "pos_x");
-	if (ret->pos_x == NULL)
-		fprintf(stderr, "Continent has no pos_x\n");
+	if (ret->pos_x == NULL) {
+		fprintf(stderr, "XML: 'continent' has no 'pos_x'\n");
+		goto error;
+	}
 
 	ret->pos_y = xmlGetProp(cur, (const xmlChar *) "pos_y");
-	if (ret->pos_y == NULL)
-		fprintf(stderr, "Continent has no pos_y\n");
+	if (ret->pos_y == NULL) {
+		fprintf(stderr, "XML: 'continent' has no 'pos_y'\n");
+		goto error;
+	}
 
-	cur = cur->xmlChildrenNode;
+	cur = xml_get_element_children( cur );
 	while( cur != NULL ) {
 		/* country */
 		if ( !xmlStrcmp(cur->name, (const xmlChar *) "country") ) {
@@ -146,10 +168,13 @@ parseContinent(xmlDocPtr doc, xmlNodePtr cur)
 			return(NULL);
 		}
 
-		cur = cur->next;
+		cur = xml_get_element_next( cur );
 	}
 
 	return(ret);
+error:
+	free(ret);
+	return NULL;
 }
 
 static pCards
@@ -166,7 +191,7 @@ parseCards(xmlDocPtr doc, xmlNodePtr cur)
 	
 	memset(ret, 0, sizeof(*ret));
 	
-	cur = cur->xmlChildrenNode;
+	cur = xml_get_element_children( cur );
 	while( cur != NULL ) {
 		/* card */
 		if ( !xmlStrcmp(cur->name, (const xmlChar *) "card") ) {
@@ -195,7 +220,7 @@ parseCards(xmlDocPtr doc, xmlNodePtr cur)
 			fprintf(stderr,"Wrong name(%s). card was expected\n", cur->name);
 		}
 
-		cur = cur->next;
+		cur = xml_get_element_next( cur );
 	}
 
 	return(ret);
@@ -203,11 +228,12 @@ parseCards(xmlDocPtr doc, xmlNodePtr cur)
 
 static pTheme parseTheme(char *filename)
 {
-	xmlDocPtr doc;
+	xmlDocPtr doc = NULL;
 	pContinent curcontinent = NULL;
 	pCards curcards = NULL;
 	xmlNodePtr cur;
 	pTheme ret = NULL;
+	xmlChar *theme_version;
 
 	/*
 	 * build an XML tree from a the file;
@@ -230,6 +256,43 @@ static pTheme parseTheme(char *filename)
 		goto error;
 	}
 
+	/* find theme version */
+	theme_version = xmlGetProp(cur, (const xmlChar *) "version");
+	if (theme_version== NULL) {
+		fprintf(stderr, "XML: 'teg_theme' has no 'version'\n");
+		goto error;
+	}
+	/* compare versions */
+	{
+		int ver_major, ver_minor;
+		char *ret;
+
+		ret = strchr( theme_version, '.' );
+
+		if( ret ) {
+			ver_minor = atoi( ret+1);
+			*ret = 0;
+		} else
+			ver_minor = 0;
+
+		ver_major = atoi( theme_version );
+
+#ifdef _DEBUG
+		fprintf( stderr, "major:%d, minor: %d\n", ver_major, ver_minor );
+#endif
+
+		if( ver_major != TEG_THEME_VER_MAJOR || ver_minor > TEG_THEME_VER_MINOR)
+		{
+			fprintf(stderr, "XML: The version of the XML is incompatible.\n . Supported theme version are %d.x where x is <= %d\n . Current theme version is:%d.%d\n"
+					,TEG_THEME_VER_MAJOR
+					,TEG_THEME_VER_MINOR
+					,ver_major
+					,ver_minor );
+			goto error;
+		}
+	}
+
+
 	/*
 	 * Allocate the structure to be returned.
 	 */
@@ -243,39 +306,43 @@ static pTheme parseTheme(char *filename)
 	/*
 	 * Now, walk the tree.
 	 */
-	cur = cur->xmlChildrenNode;
+	cur = xml_get_element_children( cur );
 #if 0
 	while ( cur && xmlIsBlankNode ( cur ) ) {
 		cur = cur -> next;
 	}
 #endif
-	if ( cur == 0 ) {
-		free( ret );
-		return ( NULL );
-	}
+	if ( cur == 0 )
+		goto error;
 
 	while (cur != NULL) {
 
 		/* author */
 		if (!xmlStrcmp(cur->name, (const xmlChar *) "author") ) {
 			ret->author = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
-			if (ret->author== NULL)
+			if (ret->author== NULL) {
 				fprintf(stderr, "Theme:Author is empty\n");
+				goto error;
+			}
 		}
 
 		/* email */
 		else if (!xmlStrcmp(cur->name, (const xmlChar *) "email") ) {
 			ret->email = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
-			if (ret->email== NULL)
+			if (ret->email== NULL){
 				fprintf(stderr, "Theme:Email is empty\n");
+				goto error;
+			}
 		}
 
 
 		/* version */
 		else if (!xmlStrcmp(cur->name, (const xmlChar *) "version") ) {
 			ret->version= xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
-			if (ret->version == NULL)
+			if (ret->version == NULL) {
 				fprintf(stderr, "Theme:version is empty\n");
+				goto error;
+			}
 		}
 
 
@@ -299,48 +366,167 @@ static pTheme parseTheme(char *filename)
 		/* board */
 		else if (!xmlStrcmp(cur->name, (const xmlChar *) "board") ) {
 			ret->board = xmlGetProp(cur, (const xmlChar *) "file");
-			if (ret->board == NULL)
-				fprintf(stderr, "Board has no name\n");
+			if (ret->board == NULL) {
+				fprintf(stderr, "XML: 'board' has no name\n");
+				goto error;
+			}
 		}
 
 		/* armies pos */
 		else if (!xmlStrcmp(cur->name, (const xmlChar *) "armies_pos") ) {
 
 			ret->armies_x = xmlGetProp(cur, (const xmlChar *) "x");
-			if (ret->armies_x== NULL)
-				fprintf(stderr, "Armies_pos has no x\n");
+			if (ret->armies_x== NULL) {
+				fprintf(stderr, "XML: 'armies_pos' has no x\n");
+				goto error;
+			}
 			ret->armies_y = xmlGetProp(cur, (const xmlChar *) "y");
-			if (ret->armies_y== NULL)
-				fprintf(stderr, "Armies_pos has no y\n");
-		}
+			if (ret->armies_y== NULL) {
+				fprintf(stderr, "XML: 'armies_pos' has no y\n");
+				goto error;
+			}
 
+			/* optional */
+			ret->armies_background = xmlGetProp(cur, (const xmlChar *) "background");
+			ret->armies_dragable = xmlGetProp(cur, (const xmlChar *) "dragable");
+		}
 
 		/* dices pos */
 		else if (!xmlStrcmp(cur->name, (const xmlChar *) "dices_pos") ) {
 
 			ret->dices_x = xmlGetProp(cur, (const xmlChar *) "x");
-			if (ret->dices_x== NULL)
-				fprintf(stderr, "Dices_pos has no x\n");
+			if (ret->dices_x == NULL) {
+				fprintf(stderr, "XML: 'dices_pos' has no x\n");
+				goto error;
+			}
 			ret->dices_y = xmlGetProp(cur, (const xmlChar *) "y");
-			if (ret->dices_y== NULL)
-				fprintf(stderr, "Dices_pos has no y\n");
+			if (ret->dices_y == NULL) {
+				fprintf(stderr, "XML: 'dices_pos' has no y\n");
+				goto error;
+			}
 		}
 
+
 		/* dices text */
 		else if (!xmlStrcmp(cur->name, (const xmlChar *) "dices_text") ) {
 
+			int i;
+			char buf[16];
+
 			ret->dices_color = xmlGetProp(cur, (const xmlChar *) "color");
-			if (ret->dices_color== NULL)
-				fprintf(stderr, "Dices_text has no color\n");
+			if (ret->dices_color== NULL) {
+				fprintf(stderr, "XML: 'dices_text' has no color\n");
+				goto error;
+			}
+
+			/* extended dices support for text. It is optional in dices_text */
+			for(i=0;i<2;i++) {
+				/* x */
+				sprintf(buf,"x%d",i+1);
+				ret->dices_ext_text_x[i] = xmlGetProp(cur, (const xmlChar *) buf);
+				/* y */
+				sprintf(buf,"y%d",i+1);
+				ret->dices_ext_text_y[i] = xmlGetProp(cur, (const xmlChar *) buf);
+			}
 		}
 
+		/* extended dices support */
+		else if (!xmlStrcmp(cur->name, (const xmlChar *) "dices_ext_pos") ) {
+			int i;
+			char buf[16];
+
+#ifdef _DEBUG
+			fprintf( stderr, "Found extended dices support\n");
+#endif
+			for(i=0;i<6;i++) {
+				/* x */
+				sprintf(buf,"x%d",i+1);
+				ret->dices_ext_x[i] = xmlGetProp(cur, (const xmlChar *) buf);
+				if( ret->dices_ext_x[i] == NULL ) {
+					fprintf(stderr, "XML: 'dices_ext_pos' has no '%s'\n",buf);
+					goto error;
+				}
+
+				/* y */
+				sprintf(buf,"y%d",i+1);
+				ret->dices_ext_y[i] = xmlGetProp(cur, (const xmlChar *) buf);
+				if( ret->dices_ext_y[i] == NULL ) {
+					fprintf(stderr, "XML: 'dices_ext_pos' has no '%s'\n",buf);
+					goto error;
+				}
+			}
+		}
+
+		/* choose_colors (optional) */
+		else if (!xmlStrcmp(cur->name, (const xmlChar *) "choose_colors") ) {
+
+			/* custom */
+			ret->choose_colors_custom = xmlGetProp(cur, (const xmlChar *) "custom");
+
+			/* prefix */
+			ret->choose_colors_prefix = xmlGetProp(cur, (const xmlChar *) "prefix");
+		}
+
+		/* toolbar (optional) */
+		else if (!xmlStrcmp(cur->name, (const xmlChar *) "toolbar") ) {
+
+			/* custom */
+			ret->toolbar_custom = xmlGetProp(cur, (const xmlChar *) "custom");
+
+			/* name */
+			ret->toolbar_name = xmlGetProp(cur, (const xmlChar *) "name");
+
+			/* text_color */
+			ret->toolbar_text_color = xmlGetProp(cur, (const xmlChar *) "text_color");
+
+			/* offset left */
+			ret->toolbar_offset_left = xmlGetProp(cur, (const xmlChar *) "offset_left");
+
+			/* offset right */
+			ret->toolbar_offset_right = xmlGetProp(cur, (const xmlChar *) "offset_right");
+		}
+
+
+
 		/* screenshot */
 		else if (!xmlStrcmp(cur->name, (const xmlChar *) "screenshot") ) {
 			ret->screenshot = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
-			if (ret->screenshot== NULL)
-				fprintf(stderr, "Theme:Screenshot is empty\n");
+			if (ret->screenshot== NULL) {
+				fprintf(stderr, "XML: 'screenshot' is empty\n");
+				goto error;
+			}
 		}
 
+		/* screen */
+		else if (!xmlStrcmp(cur->name, (const xmlChar *) "screen") ) {
+			ret->screen_size_x = xmlGetProp(cur, (const xmlChar *) "size_x");
+			if (ret->screen_size_x == NULL) {
+				fprintf(stderr, "XML: 'screen' has no size_x\n");
+				goto error;
+			}
+			ret->screen_size_y = xmlGetProp(cur, (const xmlChar *) "size_y");
+			if (ret->screen_size_x == NULL) {
+				fprintf(stderr, "XML: 'screen' has no size_y\n");
+				goto error;
+			}
+		}
+
+		/* map */
+		else if (!xmlStrcmp(cur->name, (const xmlChar *) "map") ) {
+			ret->board = xmlGetProp(cur, (const xmlChar *) "file");
+			if (ret->board == NULL) {
+				fprintf(stderr, "XML: 'board' has no name\n");
+				goto error;
+			}
+			ret->board_x = xmlGetProp(cur, (const xmlChar *) "offset_x");
+			if (ret->board_x == NULL) {
+			  ret->board_x =  "0";
+			}
+			ret->board_y = xmlGetProp(cur, (const xmlChar *) "offset_y");
+			if (ret->board_y == NULL) {
+			  ret->board_y = "0";
+			}
+		}
 #ifdef XML_WORKS_OK
 		/* dices file */
 		else  if (!xmlStrcmp(cur->name, (const xmlChar *) "dices_file") ) {
@@ -358,19 +544,22 @@ static pTheme parseTheme(char *filename)
 		}
 #endif	/* XML_WORKS_OK */
 		else {
-			fprintf(stderr,"Wrong type (%s). continent, board and dices was expected\n", cur->name);
+			fprintf(stderr,"Wrong type (%s). 'continent', 'board' or 'map', 'screen' and 'dices' were expected\n", cur->name);
 			free(ret);
 			goto error;
 		}
 
-		cur = cur->next;
+		cur = xml_get_element_next( cur );
 	}
 
 	xmlFreeDoc(doc);
 	return(ret);
 
 error:
-	xmlFreeDoc(doc);
+	if( doc )
+		xmlFreeDoc(doc);
+	if( ret )
+		free(ret);
 	return(NULL);
 }
 
@@ -384,7 +573,7 @@ static TEG_STATUS theme_fill_country_name()
 	l=0;
 	for(j=0;j<g_theme->i_continent;j++) {
 		for(k=0;k<g_theme->continents[j]->i_country;k++) {
-			g_paises[l++].nombre = g_theme->continents[j]->countries[k]->name;
+			g_countries[l++].name = g_theme->continents[j]->countries[k]->name;
 		}
 	}
 
@@ -399,18 +588,13 @@ static TEG_STATUS theme_fill_continent_name()
 		return TEG_STATUS_ERROR;
 
 	for(i=0;i<g_theme->i_continent;i++) {
-		g_conts[i].nombre = g_theme->continents[i]->name;
+		g_conts[i].name = g_theme->continents[i]->name;
 	}
 
 	return TEG_STATUS_SUCCESS;
 }
 
-
-
-/**
- * @fn TEG_STATUS theme_load( char *name)
- * Loads the 'name' theme
- */
+/* Loads the 'name' theme */
 TEG_STATUS theme_load( char *name)
 {
 	char filename[512];
@@ -454,10 +638,6 @@ void theme_unload()
 {
 }
 
-/**
- * @fn TEG_STATUS theme_giveme_cards(pTCards pC)
- * return the cards
- */
 TEG_STATUS theme_giveme_cards(pTCards pC)
 {
 	if( g_theme == NULL )
@@ -472,9 +652,6 @@ TEG_STATUS theme_giveme_cards(pTCards pC)
 	return TEG_STATUS_SUCCESS;
 }
 
-/**
- * @fn TEG_STATUS theme_giveme_continent(pTContinent pC, int n)
- */
 TEG_STATUS theme_giveme_continent(pTContinent pC, int n)
 {
 	if( g_theme == NULL )
@@ -488,9 +665,7 @@ TEG_STATUS theme_giveme_continent(pTContinent pC, int n)
 
 	return TEG_STATUS_SUCCESS;
 }
-/**
- * @fn TEG_STATUS theme_giveme_country(pTCountry pC, int n)
- */
+
 TEG_STATUS theme_giveme_country(pTCountry pC, int cont, int n)
 {
 	if( g_theme == NULL )
@@ -512,10 +687,6 @@ TEG_STATUS theme_giveme_country(pTCountry pC, int cont, int n)
 	return TEG_STATUS_SUCCESS;
 }
 
-/**
- * @fn TEG_STATUS theme_giveme_theme(pTTheme pT)
- * returns the theme
- */
 TEG_STATUS theme_giveme_theme(pTTheme pT)
 {
 	int i;
@@ -526,11 +697,28 @@ TEG_STATUS theme_giveme_theme(pTTheme pT)
 	pT->author= g_theme->author;
 	pT->email = g_theme->email;
 	pT->version = g_theme->version;
+	pT->screen_size_x = my_atoi ( g_theme->screen_size_x );
+	if ( pT->screen_size_x == -1)
+	  pT->screen_size_x = 640;
+	pT->screen_size_y = my_atoi ( g_theme->screen_size_y );
+	if ( pT->screen_size_y == -1)
+	  pT->screen_size_y = 480;
 	pT->board = g_theme->board;
-	pT->dices_x= atoi( g_theme->dices_x );
-	pT->dices_y= atoi( g_theme->dices_y );
-	pT->armies_x= atoi( g_theme->armies_x );
-	pT->armies_y= atoi( g_theme->armies_y );
+	pT->board_x = my_atoi( g_theme->board_x );
+	pT->board_y = my_atoi( g_theme->board_y );
+
+	pT->dices_x = my_atoi( g_theme->dices_x );
+	pT->dices_y = my_atoi( g_theme->dices_y );
+	pT->armies_x = atoi( g_theme->armies_x );
+	pT->armies_y = atoi( g_theme->armies_y );
+
+	pT->armies_background = 1;	/* default */
+	if( g_theme->armies_background )
+		pT->armies_background = ( strcasecmp(g_theme->armies_background, "true" ) == 0 );
+
+	pT->armies_dragable = 1;	/* default */
+	if( g_theme->armies_background )
+		pT->armies_dragable = ( strcasecmp(g_theme->armies_background, "true" ) == 0 );
 
 	for(i=0;i<DICES_CANT;i++)
 		pT->dices_file[i] = g_theme->dices_file[i];
@@ -538,13 +726,41 @@ TEG_STATUS theme_giveme_theme(pTTheme pT)
 	pT->dices_color = g_theme->dices_color;
 	pT->screenshot = g_theme->screenshot;
 
+	/* optional features */
+
+	/* extended dices support. This is an optional feature. See Draco Theme */
+	for(i=0;i<6;i++)
+	{
+		pT->dices_ext_x[i] = my_atoi( g_theme->dices_ext_x[i] );
+		pT->dices_ext_y[i] = my_atoi( g_theme->dices_ext_y[i] );
+	}
+
+	for(i=0;i<2;i++)
+	{
+		pT->dices_ext_text_x[i] = my_atoi( g_theme->dices_ext_text_x[i] );
+		pT->dices_ext_text_y[i] = my_atoi( g_theme->dices_ext_text_y[i] );
+	}
+
+	pT->choose_colors_custom = 0;
+	pT->choose_colors_prefix = NULL;
+	if( g_theme->choose_colors_custom && strcasecmp(g_theme->choose_colors_custom,"true") == 0 )
+		pT->choose_colors_custom = 1;
+	pT->choose_colors_prefix = g_theme->choose_colors_prefix;
+
+	pT->toolbar_custom = 0;
+	pT->toolbar_name = NULL;
+	pT->toolbar_text_color = NULL;
+	if( g_theme->toolbar_custom && strcasecmp(g_theme->toolbar_custom,"true") == 0 )
+		pT->toolbar_custom = 1;
+	pT->toolbar_name = g_theme->toolbar_name;
+	pT->toolbar_text_color = g_theme->toolbar_text_color;
+	pT->toolbar_offset_left = my_atoi( g_theme->toolbar_offset_left);
+	pT->toolbar_offset_right = my_atoi( g_theme->toolbar_offset_right);
+
 	return TEG_STATUS_SUCCESS;
 }
 
-/**
- * @fn TEG_STATUS theme_enum_themes( pTInfo pTI )
- * builds a list of available themes
- */
+/* builds a list of available themes */
 TEG_STATUS theme_enum_themes( pTInfo pTI )
 {
 	char *dname = "themes";
@@ -644,13 +860,7 @@ void theme_free()
 	}
 }
 
-
-/**
- * @fn char * theme_load_file( char *name )
- * Finds the path for a filename
- * @param name filename to find
- * @return NULL if not found, else the correct path to the file
- */
+/* Finds the path for a filename */
 char * theme_load_file( char *name )
 {
 	FILE *fp;
@@ -658,15 +868,15 @@ char * theme_load_file( char *name )
 
 	memset(buf,0,sizeof(buf));
 
-	snprintf(buf,sizeof(buf)-1,"themes/%s/%s",g_juego.theme,name);
+	snprintf(buf,sizeof(buf)-1,"themes/%s/%s",g_game.theme,name);
 	fp = fopen(buf,"r");
 	if( fp == NULL ) {
-		snprintf(buf,sizeof(buf)-1,"%s/%s/themes/%s/%s",g_get_home_dir(),TEG_DIRRC,g_juego.theme,name);
+		snprintf(buf,sizeof(buf)-1,"%s/%s/themes/%s/%s",g_get_home_dir(),TEG_DIRRC,g_game.theme,name);
 		fp = fopen(buf,"r");
 	}
 
 	if( fp == NULL ) {
-		snprintf(buf,sizeof(buf)-1,"%s/%s/%s",THEMEDIR,g_juego.theme,name);
+		snprintf(buf,sizeof(buf)-1,"%s/%s/%s",THEMEDIR,g_game.theme,name);
 		fp = fopen(buf,"r");
 	}
 
@@ -677,10 +887,7 @@ char * theme_load_file( char *name )
 	return buf;
 }
 
-/**
- * @fn char * theme_load_fake_file( char *name, char *theme )
- * Loads a pixmap of a not loaded theme
- */
+/* Loads a pixmap of a not loaded theme */
 char * theme_load_fake_file( char *name, char *theme )
 {
 	FILE *fp;
@@ -706,3 +913,13 @@ char * theme_load_fake_file( char *name, char *theme )
 	fclose(fp);
 	return buf;
 }
+
+int theme_using_extended_dices()
+{
+	if( g_theme == NULL ) {
+		fprintf(stderr,"theme_using_extended() cant be called before loading a theme!\n");
+		return 0;
+	}
+
+	return ( my_atoi( g_theme->dices_ext_x[0] ) != -1 );
+}
