@@ -1,4 +1,4 @@
-/*	$Id: stats.c,v 1.3 2001/11/11 00:35:43 riq Exp $	*/
+/*	$Id: stats.c,v 1.4 2002/05/25 18:38:14 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -34,8 +34,15 @@ TEG_STATUS stats_init( PPLAYER_STATS s )
 
 TEG_STATUS stats_score( PPLAYER_STATS s )
 {
-	s->score = ( s->countries_won - s->countries_lost ) * 5 +
-			( s->armies_won - s->armies_lost ) * 2;
+	int i;
+
+	/* points for armies, countries */
+	s->score =  s->countries_won * 5 +
+		s->armies_killed  * 2;
+
+	/* points for defending continents */
+	for(i=0;i<CONT_CANT;i++)
+		s->score += s->continents_turn[i] * g_conts[i].fichas_x_cont;
 
 	return TEG_STATUS_SUCCESS;
 }
