@@ -1,4 +1,4 @@
-/*	$Id: ai.h,v 1.7 2001/09/03 00:55:40 riq Exp $	*/
+/*	$Id: ai.h,v 1.8 2002/08/31 17:45:59 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -26,8 +26,8 @@
 #ifndef __TEGR_AI_H
 #define __TEGR_AI_H
 
-extern int ai_puntaje[PAISES_CANT];
-extern int ai_sorted[PAISES_CANT];
+extern int ai_puntaje[COUNTRIES_CANT];
+extern int ai_sorted[COUNTRIES_CANT];
 
 TEG_STATUS ai_fichas( int cant );
 TEG_STATUS ai_fichasc( int cant, int conts);
