@@ -1,4 +1,4 @@
-/*	$Id: turno.h,v 1.11 2001/11/26 05:45:56 riq Exp $	*/
+/*	$Id: turno.h,v 1.13 2002/08/13 03:28:49 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2001 Ricardo Quesada
@@ -26,18 +26,20 @@
 #define __TEG_TURNO_H
 
 #include "server.h"
-/*
- * Funciones y variables exportadas
- */
+
+/*! give turn to next player */
 TEG_STATUS turno_next( void );
+/*! initialize the turn */
 TEG_STATUS turno_init(void);
-/**! give the turn to the next player */
-TEG_STATUS turno_2nextplayer( PJUGADOR *j );
-/**! give the turn to the previous player */
-TEG_STATUS turno_2prevplayer( PJUGADOR *ppj );
-/**! ends the turn for a player */
-TEG_STATUS turno_end( PJUGADOR pJ );
-/**! says if the round is completed */
+/*! give the turn to the next player */
+TEG_STATUS turno_2nextplayer( PSPLAYER *j );
+/*! give the turn to the previous player */
+TEG_STATUS turno_2prevplayer( PSPLAYER *ppj );
+/*! ends the turn for a player */
+TEG_STATUS turno_end( PSPLAYER pJ );
+/*! says if the round is completed */
 BOOLEAN turno_is_round_complete( void );
+/*! called when a round is complete */
+void turno_initialize_new_round( void );
 
 #endif /* __TEG_TURNO_H */
